@@ -11,7 +11,7 @@ struct HelloTemplate<'a> {
 
 #[actix_rt::test]
 async fn test_actix_web() {
-    let srv = actix_web::test::start(|| {
+    let srv = actix_test::start(|| {
         actix_web::App::new()
             .service(web::resource("/").to(|| async { HelloTemplate { name: "world" } }))
     });
@@ -30,7 +30,7 @@ async fn test_actix_web() {
 
 #[actix_rt::test]
 async fn test_actix_web_responder() {
-    let srv = actix_web::test::start(|| {
+    let srv = actix_test::start(|| {
         actix_web::App::new().service(web::resource("/").to(|| async {
             let name = "world".to_owned();
             HelloTemplate { name: &name }.to_response()
